<?php
/**
 * BootstrapTheme functions and definitions
 *
 * @package BootstrapTheme
 */

/**
 * Set the content width based on the theme's design and stylesheet.
 */
if ( ! isset( $content_width ) ) {
	$content_width = 640; /* pixels */
}

if ( ! function_exists( 'bootstraptheme_setup' ) ) :
/**
 * Sets up theme defaults and registers support for various WordPress features.
 *
 * Note that this function is hooked into the after_setup_theme hook, which
 * runs before the init hook. The init hook is too late for some features, such
 * as indicating support for post thumbnails.
 */
function bootstraptheme_setup() {

	/*
	 * Make theme available for translation.
	 * Translations can be filed in the /languages/ directory.
	 * If you're building a theme based on BootstrapTheme, use a find and replace
	 * to change 'bootstraptheme' to the name of your theme in all the template files
	 */
	load_theme_textdomain( 'bootstraptheme', get_template_directory() . '/languages' );

	// Add default posts and comments RSS feed links to head.
	add_theme_support( 'automatic-feed-links' );

	/*
	 * Enable support for Post Thumbnails on posts and pages.
	 *
	 * @link http://codex.wordpress.org/Function_Reference/add_theme_support#Post_Thumbnails
	 */
	//add_theme_support( 'post-thumbnails' );

	// This theme uses wp_nav_menu() in one location.
//	register_nav_menus( array(
//		'primary' => __( 'Primary Menu', 'bootstraptheme' ),
//	) );

	// Enable support for Post Formats.
	add_theme_support( 'post-formats', array( 'aside', 'image', 'video', 'quote', 'link' ) );

	// Setup the WordPress core custom background feature.
	add_theme_support( 'custom-background', apply_filters( 'bootstraptheme_custom_background_args', array(
		'default-color' => 'ffffff',
		'default-image' => '',
	) ) );
}
endif; // bootstraptheme_setup
add_action( 'after_setup_theme', 'bootstraptheme_setup' );

/**
 * Register widgetized area and update sidebar with default widgets.
 */
function bootstraptheme_widgets_init() {
	register_sidebar( array(
		'name'          => __( 'Sidebar', 'bootstraptheme' ),
		'id'            => 'sidebar-1',
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h1 class="widget-title">',
		'after_title'   => '</h1>',
	) );
}
add_action( 'widgets_init', 'bootstraptheme_widgets_init' );

/**
 * Enqueue scripts and styles.
 */
 
function bootstraptheme_scripts() {
	wp_enqueue_style( 'bootstraptheme-style', get_stylesheet_uri() );

	if (!is_admin()) add_action("wp_enqueue_scripts", "my_jquery_enqueue", 11);
	function my_jquery_enqueue() {
	   wp_deregister_script('jquery');
	   wp_register_script('jquery', "http" . ($_SERVER['SERVER_PORT'] == 443 ? "s" : "") . "://ajax.googleapis.com/ajax/libs/jquery/1.10.0/jquery.min.js", false, null);
	   wp_enqueue_script('jquery');
	}
 	
	wp_enqueue_script('jquery', "http" . ($_SERVER['SERVER_PORT'] == 443 ? "s" : "") . "://ajax.googleapis.com/ajax/libs/jquery/1.10.0/jquery.min.js", false, null);
	
	wp_enqueue_script('bootstrap-javascript', "http" . ($_SERVER['SERVER_PORT'] == 443 ? "s" : "") . "://netdna.bootstrapcdn.com/bootstrap/3.0.3/js/bootstrap.min.js", false, null);

	    
	wp_enqueue_style( 'bootstraptheme-custom-stylesheet', get_template_directory_uri().'/css/'.get_option("Select_Theme","amelia").'.min.css' );

	wp_enqueue_script( 'bootstraptheme-navigation', get_template_directory_uri() . '/js/navigation.js', array(), '20120206', true );

	wp_enqueue_script( 'bootstraptheme-skip-link-focus-fix', get_template_directory_uri() . '/js/skip-link-focus-fix.js', array(), '20130115', true );

	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}
	
}
add_action( 'wp_enqueue_scripts', 'bootstraptheme_scripts' );

/**
 * Implement the Custom Header feature.
 */
//require get_template_directory() . '/inc/custom-header.php';

/**
 * Custom template tags for this theme.
 */
require get_template_directory() . '/inc/template-tags.php';

/**
 * Custom functions that act independently of the theme templates.
 */
require get_template_directory() . '/inc/extras.php';

/**
 * Customizer additions.
 */
require get_template_directory() . '/inc/customizer.php';

/**
 * Load Jetpack compatibility file.
 */
require get_template_directory() . '/inc/jetpack.php';

/* 
* Cool Navbar
*/
require_once('wp_bootstrap_navwalker.php');

register_nav_menus( array(
    'primary' => __( 'Primary Menu', 'BootstrapTheme' ),
) );

/*
* Add theme options
*/
add_action( 'admin_menu', 'BootstrapthemeMenu' );

function BootstrapthemeMenu(){
    add_theme_page( 'Bootstrap Theme Options', 'OpenSwatch Theme Options', 'administrator', 'custompage', 'bootstraptheme_page',get_bloginfo('template_url').'/img/logo.png', 6 ); 
	
	add_action( 'admin_init', 'register_mysettings' );
}
function show_carousel(){
$link1 = get_option('carousel1-link');
$link2 = get_option('carousel2-link');
$link3 = get_option('carousel3-link');
	if((empty($link1))==true && (empty($link2))==true && (empty($link3))==true){
		return false;
	}else{
		return true;
	}
	
}
add_theme_support( 'post-thumbnails' );
global $pagenow;
if ( is_admin() && isset($_GET['activated']) && $pagenow == "themes.php" ) {
	add_action( 'admin_notices', 'theme_activated'  );
}
function theme_activated(){
	?>
	<div class="updated"><h3>Congratulations, Open Swatch theme is successfully activated. Please visit <a href="themes.php?page=custompage">Open strapper Theme settings</a> to make your site look better!</h3></div>
    <meta http-equiv="refresh" content="3; url=themes.php?page=custompage" />
    <?php ;
}


